crikit.datasets package — CRIKit2 0.4.3 documentation

# crikit.datasets package

## Submodules

## crikit.datasets.model module

class crikit.datasets.model.Model(subsample=1, dtype=<class 'complex'>)

  Bases: `object`

  Model class

  Parameters

    - subsample (int) – Subsample the spatial dimenension (ie x[::subsample], y[::subsample])

    - dtype (numpy dtype) – Dtype to set final image

  property f
  property hsi_i

    Return imag{hsi}

  property hsi_r

    Return real{hsi}

  make_hsi(f=None)

    Make the HSI image

    Parameters

      f (ndarray (1D)) – Frequency vector

  make_spectra(f)
    Parameters

      f (ndarray (1D)) – Frequency vector

  property wn

## Module contents